<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Скопіювати колір %1 до буферу обміну</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="50"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin Picker - це інструмент для швидкого вибору кольору екрану. RGB та HEX код може бути отриманий відповідно до обраного кольору та автоматично збережений в буфер обміну. Область вибору кольору - це місце, куди клацнули мишею.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="72"/>
        <source>Deepin Picker</source>
        <translation>Deepin Picker</translation>
    </message>
</context>
</TS>